#!/usr/bin/python

# Copyright (c) 2012 Henri Sivonen
#
# Permission is hereby granted, free of charge, to any person obtaining a 
# copy of this software and associated documentation files (the "Software"), 
# to deal in the Software without restriction, including without limitation 
# the rights to use, copy, modify, merge, publish, distribute, sublicense, 
# and/or sell copies of the Software, and to permit persons to whom the 
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in 
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
# DEALINGS IN THE SOFTWARE.

import sys
import re

pat = re.compile("^\"([^\"]*) (\d+)(?:\.(\d+))?\",(\d+(?:\.\d+)?)$")

theora = 0.0
webm = 0.0
h264 = 0.0
novideo = 0.0
unknown = 0.0
total = 0.0

for line in sys.stdin:
  m = pat.match(line);
  if m:
    browser = m.group(1)
    versionmajor = int(m.group(2))
    versionminor = 0
    if m.group(3):
      versionminor = int(m.group(3))
    share = float(m.group(4))
    version = versionmajor * 10 + versionminor
    if browser == "Firefox":
      total += share
      if version >= 35:
        theora += share
      else:
        novideo += share
      if version >= 40:
        webm += share
    elif browser == "SeaMonkey":
      total += share
      if version >= 20:
        theora += share
      else:
        novideo += share
      if version >= 21:
        webm += share
    elif browser == "Chrome":
      total += share
      if version >= 30:
        theora += share
        # Wikipedia does not match my recollection
        h264 += share
      else:
        novideo += share
      if version >= 60:
        webm += share
    elif browser == "Chromium":
      total += share
      if version >= 30:
        theora += share
      else:
        novideo += share
      if version >= 60:
        webm += share
    elif browser == "Opera":
      total += share
      if version >= 105:
        theora += share
      else:
        novideo += share
      if version >= 106:
        webm += share
    elif browser == "Safari":
      total += share
      if version >= 31:
        h264 += share
      else:
        novideo += share
    elif browser == "IE":
      total += share
      if version >= 90:
        h264 += share
      else:
        novideo += share
    elif browser == "Camino":
      total += share
      if version >= 21:
        theora += share
      else:
        novideo += share
    elif browser == "RockMelt":
      total += share
      unknown += share
    elif browser == "Flock":
      total += share
      unknown += share
    elif browser == "Maxthon":
      total += share
      unknown += share
    elif browser == "AOL":
      total += share
      unknown += share
    elif browser == "Comodo Dragon":
      total += share
      unknown += share
    elif browser == "Iron":
      total += share
      unknown += share

print "Desktop: %f" % total
print "Theora: %f" % (theora / total)
print "WebM: %f" % (webm / total)
print "H.264: %f" % (h264 / total)
print "None: %f" % (novideo / total)
print "Unknown: %f" % (unknown / total)



